@@ -1,12 +1,10 @@
 package POE::Component::Server::SimpleHTTP;
+$POE::Component::Server::SimpleHTTP::VERSION = '2.26';
+#ABSTRACT: Perl extension to serve HTTP requests in POE.
 
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-
-$VERSION = '2.24';
-
 use POE;
 use POE::Wheel::SocketFactory;
 use POE::Wheel::ReadWrite;
@@ -1176,10 +1174,18 @@ __PACKAGE__->meta->make_immutable( );
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::Server::SimpleHTTP - Perl extension to serve HTTP requests in POE.
 
+=head1 VERSION
+
+version 2.26
+
 =head1 SYNOPSIS
 
 	use POE;
@@ -1313,10 +1319,6 @@ POE::Component::Server::SimpleHTTP - Perl extension to serve HTTP requests in PO
 		return;
 	}
 
-=head1 ABSTRACT
-
-	An easy to use HTTP daemon for POE-enabled programs
-
 =head1 DESCRIPTION
 
 This module makes serving up HTTP requests a breeze in POE.
@@ -1694,6 +1696,19 @@ For those who are pondering about basic-authentication, here's a tiny snippet to
 
 Nothing.
 
+=for Pod::Coverage        MassageHandlers
+       START
+       STOP
+       fix_headers
+       getsockname
+       must_keepalive
+       session_id
+       shutdown
+
+=head1 ABSTRACT
+
+	An easy to use HTTP daemon for POE-enabled programs
+
 =head1 SEE ALSO
 
 	L<POE>
@@ -1714,13 +1729,13 @@ Nothing.
 
 =head1 AUTHOR
 
-Apocalypse E<lt>apocal@cpan.orgE<gt>
+Apocalypse <APOCAL@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 by Apocalypse
+This software is copyright (c) 2017 by Apocalypse, Chris Williams, Eriam Schaffter, Marlon Bailey and Philip Gwyn.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
