@@ -1,11 +1,11 @@
 # Declare our package
 package POE::Component::Server::SimpleHTTP::Connection;
+$POE::Component::Server::SimpleHTTP::Connection::VERSION = '2.26';
+#ABSTRACT: Stores connection information for SimpleHTTP
 
 use strict;
 use warnings;
 
-our $VERSION = '2.24';
-
 use Socket qw( inet_ntoa unpack_sockaddr_in );
 use POE;
 
@@ -114,10 +114,18 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::Server::SimpleHTTP::Connection - Stores connection information for SimpleHTTP
 
+=head1 VERSION
+
+version 2.26
+
 =head1 SYNOPSIS
 
 	use POE::Component::Server::SimpleHTTP::Connection;
@@ -149,6 +157,8 @@ POE::Component::Server::SimpleHTTP::Connection - Stores connection information f
 
 Nothing.
 
+=for Pod::Coverage DEMOLISH
+
 =head1 SEE ALSO
 
 L<POE::Component::Server::SimpleHTTP>,
@@ -156,15 +166,13 @@ L<POE::Component::Server::SimpleHTTP::Response>
 
 =head1 AUTHOR
 
-Apocalypse E<lt>apocal@cpan.orgE<gt>
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
+Apocalypse <APOCAL@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright E<copy> Apocalypse and Chris Williams
+This software is copyright (c) 2017 by Apocalypse, Chris Williams, Eriam Schaffter, Marlon Bailey and Philip Gwyn.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
