@@ -1,10 +1,10 @@
 package POE::Component::Server::SimpleHTTP::Response;
+$POE::Component::Server::SimpleHTTP::Response::VERSION = '2.26';
+#ABSTRACT: Emulates a HTTP::Response object, used for SimpleHTTP
 
 use strict;
 use warnings;
 
-our $VERSION = '2.24';
-
 use base qw( HTTP::Response );
 
 use Moose;
@@ -92,10 +92,18 @@ __PACKAGE__->meta->make_immutable( inline_constructor => 0 );
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::Server::SimpleHTTP::Response - Emulates a HTTP::Response object, used for SimpleHTTP
 
+=head1 VERSION
+
+version 2.26
+
 =head1 SYNOPSIS
 
 	use POE::Component::Server::SimpleHTTP::Response;
@@ -113,6 +121,8 @@ POE::Component::Server::SimpleHTTP::Response - Emulates a HTTP::Response object,
 
 Nothing.
 
+=for Pod::Coverage stream
+
 =head1 SEE ALSO
 
 	L<POE::Component::Server::SimpleHTTP>
@@ -121,13 +131,13 @@ Nothing.
 
 =head1 AUTHOR
 
-Apocalypse E<lt>apocal@cpan.orgE<gt>
+Apocalypse <APOCAL@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 by Apocalypse
+This software is copyright (c) 2017 by Apocalypse, Chris Williams, Eriam Schaffter, Marlon Bailey and Philip Gwyn.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
