@@ -1,14 +1,12 @@
 package POE::Component::Server::SimpleHTTP::State;
-
+$POE::Component::Server::SimpleHTTP::State::VERSION = '2.26';
 use strict;
 use warnings;
 use POE::Wheel::ReadWrite;
 
-our $VERSION = '2.24';
-
 use Moose;
 
-has 'wheel' => ( 
+has 'wheel' => (
   is => 'ro',
   isa => 'POE::Wheel::ReadWrite',
   clearer => 'clear_wheel',
@@ -88,3 +86,32 @@ __PACKAGE__->meta->make_immutable();
 'This monkey has gone to heaven';
 
 __END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+POE::Component::Server::SimpleHTTP::State
+
+=head1 VERSION
+
+version 2.26
+
+=for Pod::Coverage        close_wheel
+       reset
+       wheel_alive
+
+=head1 AUTHOR
+
+Apocalypse <APOCAL@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Apocalypse, Chris Williams, Eriam Schaffter, Marlon Bailey and Philip Gwyn.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
